# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['aws_cdk_update_checker']

package_data = \
{'': ['*']}

install_requires = \
['requests>=2.27.1,<3.0.0']

entry_points = \
{'console_scripts': ['acuc = '
                     'aws_cdk_update_checker.main:fetch_aws_cdk_latest_version',
                     'aws_cdk_update_checker = '
                     'aws_cdk_update_checker.main:fetch_aws_cdk_latest_version']}

setup_kwargs = {
    'name': 'aws-cdk-update-checker',
    'version': '0.0.9',
    'description': 'This script fetches latest version of AWS CDK.',
    'long_description': None,
    'author': 'otajisan',
    'author_email': 'dev@morningcode.io',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/morning-code/aws-cdk-update-checker',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



import requests


def fetch_aws_cdk_latest_version():
    json_body = fetch_aws_cdk_all_releases()
    all_releases = sorted([j['name'] for j in json_body], reverse=True)

    latest_version = all_releases[0]

    return latest_version


def fetch_aws_cdk_all_releases():
    headers = {
        'User-Agent': 'MorningCode-AWS-CDK-UPDATE-CHECKER',
        'Accept': 'application/vnd.github.v3+json',
        'Content-Type': 'application/json',
    }
    r = requests.get(get_aws_cdk_url(), headers=headers)

    if r.status_code != 200:
        raise RuntimeError(
            '[' + str(r.status_code) + '] ' +
            r'could not fetch releases from github...please try again later!'
        )

    return r.json()


def get_aws_cdk_url():
    return 'https://api.github.com/repos/aws/aws-cdk/releases'
